summaryrefslogtreecommitdiffstats
path: root/ssl.h
diff options
context:
space:
mode:
Diffstat (limited to 'ssl.h')
-rw-r--r--ssl.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/ssl.h b/ssl.h
index 06cd246..7e0bfb5 100644
--- a/ssl.h
+++ b/ssl.h
@@ -589,9 +589,10 @@ struct tls_multi
int n_soft_errors; /* errors due to unrecognized or failed-to-authenticate incoming packets */
/*
* Our locked common name (cannot change during the life of this tls_multi object)
*/
char *locked_cn;
+ char *locked_username;
#ifdef ENABLE_DEF_AUTH
/*
@@ -589,9 +589,10 @@ struct tls_multi
int n_soft_errors; /* errors due to unrecognized or failed-to-authenticate incoming packets */
/*
- * Our locked common name (cannot change during the life of this tls_multi object)
+ * Our locked common name and username (cannot change during the life of this tls_multi object)
*/
char *locked_cn;